@@ -1,9 +1,8 @@
-"""pylint-quotes module"""
-
 from __future__ import absolute_import
 
 from pylint_plus.magic_constant_checker import MagicConstantChecker  # noqa: F401
 from pylint_plus.return_method_checker import MissingReturnChecker
+from pylint_plus.function_order_checker import FunctionOrderChecker
 
 
 def plugin_register(linter):
@@ -13,6 +12,7 @@ def plugin_register(linter):
     """
     linter.register_checker(MagicConstantChecker(linter))
     linter.register_checker(MissingReturnChecker(linter))
+    linter.register_checker(FunctionOrderChecker(linter))
 
 
 register = plugin_register
